@@ -198,6 +198,10 @@ impl Parse for RespanInput {
                     respan_using: ident.span(),
                 })
             }
+            TokenTree::Ident(i) => Ok(RespanInput {
+                to_respan,
+                respan_using: i.span(),
+            }),
             val => Err(syn::Error::new_spanned(
                 val,
                 "expected None-delimited group",
